/*
 * IRC - Internet Relay Chat, ircd/m_aliases.c
 * Copyright (C) 1990 Jarkko Oikarinen and
 *                    University of Oulu, Computing Center
 *
 * See file AUTHORS in IRC package for additional names of
 * the programmers.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 1, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 */

#include "channel.h"   
#include "config.h"
#include "client.h"
#include "handlers.h"
#include "hash.h"
#include "ircd.h"
#include "ircd_defs.h"
#include "ircd_features.h"
#include "ircd_string.h"
#include "ircd_snprintf.h"
#include "ircd_alloc.h"
#include "list.h"
#include "msg.h"
#include "numeric.h"
#include "numnicks.h"
#include "querycmds.h"
#include "send.h"
#include "s_conf.h"
#include "s_user.h"
#include "s_debug.h"
#include "userload.h"  
#include "patchlevel.h"

#include <string.h>
#include <ctype.h>   
#include <stdlib.h>

int m_uworld(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  char service[NICKLEN + 1];
  char servicehost[HOSTLEN + 1];
  char msg[BUFSIZE];
  int par;
  struct Client *acptr;


  acptr = FindUser(feature_str(FEAT_UWORLD_NICK));
  strcpy(service, feature_str(FEAT_UWORLD_NICK));
  strcpy(servicehost, feature_str(FEAT_UWORLD_SERVER));

  if (parc < 2 || *parv[1] == '\0') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  if (*parv[1] == ':') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  strcpy(msg, parv[1]);
  for (par = 2; par < parc; par++) {
    strcpy(&msg[strlen(msg)], " ");
    strcpy(&msg[strlen(msg)], parv[par]);
  }

  if (FindClient(service))
    if (!MyConnect(acptr))
      sendcmdto_one(sptr, CMD_PRIVATE, acptr, "%s@%s :%s", service, servicehost, msg);
    else
      send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);
  else
    send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);

  return 0;
}


int m_x(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  char service[NICKLEN + 1];
  char servicehost[HOSTLEN + 1];
  char msg[BUFSIZE];
  int par;
  struct Client *acptr;

  acptr = FindUser(feature_str(FEAT_X_NICK));
  strcpy(service, feature_str(FEAT_X_NICK));
  strcpy(servicehost, feature_str(FEAT_X_SERVER));

  if (parc < 2 || *parv[1] == '\0') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  if (*parv[1] == ':') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  strcpy(msg, parv[1]);
  for (par = 2; par < parc; par++) {
    strcpy(&msg[strlen(msg)], " ");
    strcpy(&msg[strlen(msg)], parv[par]);
  }

  if (FindClient(service))
    if (!MyConnect(acptr))
      sendcmdto_one(sptr, CMD_PRIVATE, acptr, "%s@%s :%s", service, servicehost, msg);
    else
      send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);
  else
    send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);

  return 0;
}





int m_nickserv(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  char service[NICKLEN + 1];
  char servicehost[HOSTLEN + 1];
  char msg[BUFSIZE];
  int par;
  struct Client *acptr;


  acptr = FindUser(feature_str(FEAT_NICKSERV_NICK));
  strcpy(service, feature_str(FEAT_NICKSERV_NICK));
  strcpy(servicehost, feature_str(FEAT_NICKSERV_SERVER));

  if (parc < 2 || *parv[1] == '\0') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  if (*parv[1] == ':') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  strcpy(msg, parv[1]);
  for (par = 2; par < parc; par++) {
    strcpy(&msg[strlen(msg)], " ");
    strcpy(&msg[strlen(msg)], parv[par]);
  }

  if (FindClient(service))
    if (!MyConnect(acptr))
      sendcmdto_one(sptr, CMD_PRIVATE, acptr, "%s@%s :%s", service, servicehost, msg);
    else
      send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);
  else
    send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);

  return 0;
}





int m_chanserv(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  char service[NICKLEN + 1];
  char servicehost[HOSTLEN + 1];
  char msg[BUFSIZE];
  int par;
  struct Client *acptr;


  acptr = FindUser(feature_str(FEAT_CHANSERV_NICK));
  strcpy(service, feature_str(FEAT_CHANSERV_NICK));
  strcpy(servicehost, feature_str(FEAT_CHANSERV_SERVER));

  if (parc < 2 || *parv[1] == '\0') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  if (*parv[1] == ':') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  strcpy(msg, parv[1]);
  for (par = 2; par < parc; par++) {
    strcpy(&msg[strlen(msg)], " ");
    strcpy(&msg[strlen(msg)], parv[par]);
  }

  if (FindClient(service))
    if (!MyConnect(acptr))
      sendcmdto_one(sptr, CMD_PRIVATE, acptr, "%s@%s :%s", service, servicehost, msg);
    else
      send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);
  else
    send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);

  return 0;
}





int m_memoserv(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  char service[NICKLEN + 1];
  char servicehost[HOSTLEN + 1];
  char msg[BUFSIZE];
  int par;
  struct Client *acptr;


  acptr = FindUser(feature_str(FEAT_MEMOSERV_NICK));
  strcpy(service, feature_str(FEAT_MEMOSERV_NICK));
  strcpy(servicehost, feature_str(FEAT_MEMOSERV_SERVER));

  if (parc < 2 || *parv[1] == '\0') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  if (*parv[1] == ':') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  strcpy(msg, parv[1]);
  for (par = 2; par < parc; par++) {
    strcpy(&msg[strlen(msg)], " ");
    strcpy(&msg[strlen(msg)], parv[par]);
  }

  if (FindClient(service))
    if (!MyConnect(acptr))
      sendcmdto_one(sptr, CMD_PRIVATE, acptr, "%s@%s :%s", service, servicehost, msg);
    else
      send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);
  else
    send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);

  return 0;
}





int m_statserv(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  char service[NICKLEN + 1];
  char servicehost[HOSTLEN + 1];
  char msg[BUFSIZE];
  int par;
  struct Client *acptr;


  acptr = FindUser(feature_str(FEAT_STATSERV_NICK));
  strcpy(service, feature_str(FEAT_STATSERV_NICK));
  strcpy(servicehost, feature_str(FEAT_STATSERV_SERVER));

  if (parc < 2 || *parv[1] == '\0') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  if (*parv[1] == ':') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  strcpy(msg, parv[1]);
  for (par = 2; par < parc; par++) {
    strcpy(&msg[strlen(msg)], " ");
    strcpy(&msg[strlen(msg)], parv[par]);
  }

  if (FindClient(service))
    if (!MyConnect(acptr))
      sendcmdto_one(sptr, CMD_PRIVATE, acptr, "%s@%s :%s", service, servicehost, msg);
    else
      send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);
  else
    send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);

  return 0;
}





int m_operserv(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  char service[NICKLEN + 1];
  char servicehost[HOSTLEN + 1];
  char msg[BUFSIZE];
  int par;
  struct Client *acptr;


  acptr = FindUser(feature_str(FEAT_OPERSERV_NICK));
  strcpy(service, feature_str(FEAT_OPERSERV_NICK));
  strcpy(servicehost, feature_str(FEAT_OPERSERV_SERVER));

  if (parc < 2 || *parv[1] == '\0') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  if (*parv[1] == ':') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  strcpy(msg, parv[1]);
  for (par = 2; par < parc; par++) {
    strcpy(&msg[strlen(msg)], " ");
    strcpy(&msg[strlen(msg)], parv[par]);
  }

  if (FindClient(service))
    if (!MyConnect(acptr))
      sendcmdto_one(sptr, CMD_PRIVATE, acptr, "%s@%s :%s", service, servicehost, msg);
    else
      send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);
  else
    send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);

  return 0;
}




int m_ruleserv(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  char service[NICKLEN + 1];
  char servicehost[HOSTLEN + 1];
  char msg[BUFSIZE];
  int par;
  struct Client *acptr;


  acptr = FindUser(feature_str(FEAT_RULESERV_NICK));
  strcpy(service, feature_str(FEAT_RULESERV_NICK));
  strcpy(servicehost, feature_str(FEAT_RULESERV_SERVER));

  if (parc < 2 || *parv[1] == '\0') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  if (*parv[1] == ':') {
    send_reply(sptr, ERR_NOTEXTTOSEND);
    return -1;
  }

  strcpy(msg, parv[1]);
  for (par = 2; par < parc; par++) {
    strcpy(&msg[strlen(msg)], " ");
    strcpy(&msg[strlen(msg)], parv[par]);
  }

  if (FindClient(service))
    if (!MyConnect(acptr))
      sendcmdto_one(sptr, CMD_PRIVATE, acptr, "%s@%s :%s", service, servicehost, msg);
    else
      send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);
  else
    send_reply(sptr, ERR_SERVICESDOWN, parv[0], service);

  return 0;
}
